@@ -27,7 +27,7 @@ with this program. If not, see <https://www.gnu.org/licenses/>
 #include "../obs-websocket.h"
 #include "../utils/Obs.h"
 #include "../utils/Obs_VolumeMeter.h"
-#include "../plugin-macros.generated.h"
+#include "plugin-macros.generated.h"
 
 class EventHandler {
 public:
